import { TypedEmitter } from 'tiny-typed-emitter';
import { ConnectionInterface, ConnectionInterfaceConfiguration, ConnectionInterfaceDescription, ConnectionInterfaceEvents, ConstructableConnectionInterface } from '../connectionInterface';
type InterfaceType = 'spi' | 'spiSlave' | 'spiMaster';
declare const InterfaceType: InterfaceType;
export declare enum Phase {
    SampleLeadingEdge = 0,
    SetupLeadingEdge = 1
}
export declare enum Polarity {
    LeadingRisingEdge = 0,
    LeadingFallingEdge = 1
}
export interface SPIConfiguration extends ConnectionInterfaceConfiguration {
    signals: {
        miso: string;
        mosi: string;
        sck: string;
        ss: string;
    };
    representsAMaster: boolean;
    frequency: number;
    lsbFirst: boolean;
    clockPhase: Phase;
    clockPolarity: Polarity;
}
export type ReceiveByteEvent = {
    byte: number;
};
export interface SPISlaveInterfaceEvents extends ConnectionInterfaceEvents {
    prepareByte(event: ReceiveByteEvent): void;
}
export interface SPIMasterInterfaceEvents extends ConnectionInterfaceEvents {
    receiveByte(event: ReceiveByteEvent): void;
    slaveSelectChanged(event: ReceiveByteEvent): void;
}
export declare class SPISlaveInterface extends TypedEmitter<SPISlaveInterfaceEvents> implements ConnectionInterface {
    interfaceType: InterfaceType;
    readonly configuration: SPIConfiguration;
    constructor(configuration: SPIConfiguration);
    retransmit(): void;
    downstreamData(data: unknown): void;
    sendByte(byte: number): void;
    setSlaveSelect(value: boolean): void;
}
export declare class SPIMasterInterface extends TypedEmitter<SPIMasterInterfaceEvents> implements ConnectionInterface {
    interfaceType: InterfaceType;
    readonly configuration: SPIConfiguration;
    constructor(configuration: SPIConfiguration);
    retransmit(): void;
    downstreamData(data: unknown): void;
    prepareByte(byte: number): void;
}
export declare class ConstructableSPIInterface implements ConstructableConnectionInterface {
    interfaceType: InterfaceType;
    private signals;
    constructor(signals: string[]);
    getDescription(): ConnectionInterfaceDescription;
    create(configuration: SPIConfiguration): SPISlaveInterface | SPIMasterInterface;
}
export {};
//# sourceMappingURL=connectionInterface.d.ts.map